@@ -1,3 +1,5 @@
+from __future__ import division
+
 import base64
 
 import cv2
@@ -53,3 +55,26 @@ def encode_image(img):
     else:
         img = encode_image_cv2(img)
     return img
+
+
+def resize_keeping_aspect_ratio(img, width=None, height=None):
+    if (width and height) or (width is None and height is None):
+        raise ValueError('Only width or height should be specified.')
+    if width:
+        height = width * img.shape[0] / img.shape[1]
+    else:
+        width = height * img.shape[1] / img.shape[0]
+    height = int(height)
+    width = int(width)
+    return cv2.resize(img, (width, height))
+
+
+def resize_keeping_aspect_ratio_wrt_longside(img, length):
+    H, W = img.shape[:2]
+    aspect = W / H
+    if H > W:
+        width = length * aspect
+        return cv2.resize(img, (int(width), int(length)))
+    else:
+        height = length / aspect
+        return cv2.resize(img, (int(length), int(height)))
