@@ -9,6 +9,15 @@ from tempfile import NamedTemporaryFile
 import skvideo.io
 
 
+def hhmmss_to_seconds(ts):
+    try:
+        return float(ts)
+    except ValueError:
+        return sum(
+            float(x) * 60 ** i
+            for i, x in enumerate(reversed(ts.split(':'))))
+
+
 def get_video_duration(video_path):
     video_path = str(video_path)
     if not osp.exists(video_path):
